# core/service/rss.py
#
#

""" rss module. """

__copyright__ = "Copyright 2014 B.H.J Thate"

## IMPORTS

from core.utils import parse_urls, short_date, fetch_url, error, strip_html
from core.object import Object
from core.looper import Looper
from core import kernel

import threading
import logging
import socket
import time

## DEFINES

key_list = ["title", "summary", "link"]

seen = Object()
seen.ctype = "rss_result"
seen.list = []

on_start = True

## display function

def display(*args, **kwargs):
    entry = args[0]
    counter = args[1]
    result = ""
    kernel.announce(" ")
    for key in key_list:
        try: kernel.announce("%s %s" % (counter, entry[key]))
        except Exception as ex: logging.info(str(ex))

## look function

def rss_fetch(*args, **kwargs):
    global on_start
    import core.contrib.feedparser as fp
    for obj in kernel.objects():
        if "rss" not in obj: continue
        counter = 1
        try: data = fetch_url("GET", obj.rss).read()
        except socket.error: error() ; continue
        try: data = fp.parse(data)
        except Exception as ex: error() ; continue
        for entry in data["entries"]:
            if entry["link"] in seen.list: continue
            seen.list.append(entry["link"])
            counter += 1
            o = Object(entry).slice(key_list)
            if "summary" in o: o["summary"] = strip_html(o["summary"]).rstrip()
            o.prefix = "rss.data"
            o.sync()
            display(o, counter)
    seen.sync()

kernel.cmnds.register("fetch", rss_fetch)

def rss_search(event):
    item = event.get_rest()
    for url in seen.list:
        if item in url: event.reply(url)

kernel.cmnds.register("url", rss_search)

## INIT

def init(*args, **kwargs):
    global seen
    seen = kernel.last("ctype", "rss_result")
    if not seen: seen = Object() ; seen.list = []
    rss = Looper(rss_fetch, 600)
    kernel.run.rss = rss
    kernel.workers.put(rss.start)
